@@ -19,25 +19,29 @@
 import logging
 from typing import List
 
+import pyrogram
 from pyrogram import raw
 from pyrogram import types
-from pyrogram.scaffold import Scaffold
 
 log = logging.getLogger(__name__)
 
 
-class GetContacts(Scaffold):
-    async def get_contacts(self) -> List["types.User"]:
+class GetContacts:
+    async def get_contacts(
+        self: "pyrogram.Client"
+    ) -> List["types.User"]:
         """Get contacts from your Telegram address book.
 
+        .. include:: /_includes/usable-by/users.rst
+
         Returns:
             List of :obj:`~pyrogram.types.User`: On success, a list of users is returned.
 
         Example:
             .. code-block:: python
 
-                contacts = app.get_contacts()
+                contacts = await app.get_contacts()
                 print(contacts)
         """
-        contacts = await self.send(raw.functions.contacts.GetContacts(hash=0))
+        contacts = await self.invoke(raw.functions.contacts.GetContacts(hash=0))
         return types.List(types.User._parse(self, user) for user in contacts.users)
